summaryrefslogtreecommitdiffstats
path: root/perl-install/install/any.pm
diff options
context:
space:
mode:
authorAhmad Samir <ahmad@mageia.org>2011-04-02 19:39:51 +0000
committerAhmad Samir <ahmad@mageia.org>2011-04-02 19:39:51 +0000
commitb669b354a83790133e9d1be5c7796594bf9cfe22 (patch)
treeaa0ec2ee89a4aee11369bb5ebb3f3997526438b3 /perl-install/install/any.pm
parent14d4269e46245ec89e8106428f558973b127d3b2 (diff)
downloaddrakx-backup-do-not-use-b669b354a83790133e9d1be5c7796594bf9cfe22.tar
drakx-backup-do-not-use-b669b354a83790133e9d1be5c7796594bf9cfe22.tar.gz
drakx-backup-do-not-use-b669b354a83790133e9d1be5c7796594bf9cfe22.tar.bz2
drakx-backup-do-not-use-b669b354a83790133e9d1be5c7796594bf9cfe22.tar.xz
drakx-backup-do-not-use-b669b354a83790133e9d1be5c7796594bf9cfe22.zip
- use 'cannot' instead of 'can not'
- use 'LDAP' instead of 'Ldap'
Diffstat (limited to 'perl-install/install/any.pm')
-rw-r--r--perl-install/install/any.pm6
1 files changed, 3 insertions, 3 deletions
diff --git a/perl-install/install/any.pm b/perl-install/install/any.pm
index 76ac3d561..3ff267585 100644
--- a/perl-install/install/any.pm
+++ b/perl-install/install/any.pm
@@ -91,7 +91,7 @@ sub preConfigureTimezone {
my ($o) = @_;
require timezone;
#- can not be done in install cuz' timeconfig %post creates funny things
add2hash($o->{timezone}, timezone::read()) if $o->{isUpgrade};
$o->{timezone}{timezone} ||= timezone::bestTimezone($o->{locale}{country});
@@ -890,7 +890,7 @@ sub generate_automatic_stage1_params {
my @l = install::ftp::parse_ftp_url($ENV{URLPREFIX});
@ks = (server => $l[0], directory => $l[1], user => $l[2], pass => $l[3]);
} elsif ($o->{method} eq 'nfs') {
- cat_("/proc/mounts") =~ m|(\S+):(\S+)\s+/tmp/media| or internal_error("can not find nfsimage");
+ cat_("/proc/mounts") =~ m|(\S+):(\S+)\s+/tmp/media| or internal_error("cannot find nfsimage");
@ks = (server => $1, directory => $2);
}
@ks = (method => $method, @ks);
@@ -998,7 +998,7 @@ sub migrate_device_names {
goto found_one;
}
#- we can not find one and only one matching hd
my @from_fstab_not_handled = map { @$_ } @from_fstab_per_hds;
log::l("we still do not know what to do with: " . join(' ', map { $_->{device} } @from_fstab_not_handled));
@@ -91,7 +91,7 @@ sub preConfigureTimezone {
my ($o) = @_;
require timezone;
- #- can not be done in install cuz' timeconfig %post creates funny things
+ #- cannot be done in install cuz' timeconfig %post creates funny things
add2hash($o->{timezone}, timezone::read()) if $o->{isUpgrade};
$o->{timezone}{timezone} ||= timezone::bestTimezone($o->{locale}{country});
@@ -998,7 +998,7 @@ sub migrate_device_names {
goto found_one;
}
- #- we can not find one and only one matching hd
+ #- we cannot find one and only one matching hd
my @from_fstab_not_handled = map { @$_ } @from_fstab_per_hds;
log::l("we still do not know what to do with: " . join(' ', map { $_->{device} } @from_fstab_not_handled));